@@ -115,9 +115,11 @@ def smooth_original(forest,curve_sample_size_min=5,curve_sample_size_max=21,curv
 def smooth(forest,curve_sample_size_min=5,curve_sample_size_max=21,curve_degree=3):
     #FOREST_CONNECT_COPY = deepcopy(forest)
     connections = []
+    splines     = []
     for network in range(forest.number_of_networks):
         if not np.any(forest.connections[network][0] is None):
             network_connections = []
+            network_splines     = []
             for tree in range(forest.trees_per_network[network]):
                 tree_assignment = forest.assignments[network][tree]
                 idx = max(forest.networks[network][tree].data[:,-1]) + 1
@@ -173,6 +175,7 @@ def smooth(forest,curve_sample_size_min=5,curve_sample_size_max=21,curve_degree=
                     #else:
                     #curve.ctrlpts = [ctr_0,ctr_1,ctr_2,ctr_3]
                     curve.knotvector = utilities.generate_knot_vector(curve.degree,len(curve.ctrlpts))
+                    network_splines.append(deepcopy(curve))
                     while samples <= curve_sample_size_max and not success:
                         curve.sample_size = samples
                         curve.evaluate()
@@ -217,8 +220,32 @@ def smooth(forest,curve_sample_size_min=5,curve_sample_size_max=21,curve_degree=
                         #    tree_connection_edges[-1][16] = -1
                         #    tmp[17] = tree_connection_edges[-1][-1]
                         tree_connection_edges.append(tmp.tolist())
+
                 network_connections.append(np.array(tree_connection_edges))
             connections.append(network_connections)
+            splines.append(network_splines)
         else:
             connections.append([None])
+    return connections, None, splines
+
+
+def get_angle(V1,V2):
+    return np.arccos(np.dot(V1,V2))*(180/np.pi)
+
+def smooth_new(forest,max_angle=45):
+    connections = []
+    for network in range(forest.number_of_networks):
+        if not np.any(forest.connections[network][0] is None):
+            network_connections = []
+            for tree in range(forest.trees_per_network[network]):
+                idx = max(forest.networks[network][tree].data[:,-1]) + 1
+                tree_connection_edges = []
+                for edge in range(len(forest.connections[network][0])):
+                    edge_1   = forest.assignments[network][0][edge]
+                    edge_2   = forest.assignemnts[network][1][edge]
+                    match_vector = forest.networks[network][0].data[edge_1,3:6] - forest.networks[network][1].data[edge_2,3:6]
+                    match_vector = match_vector/np.linalg.norm(match_vector)
+                    vector_1 = forest.networks[network][0].data[edge_1,12:15]
+                    vector_2 = forest.networks[network][1].data[edge_2,12:15]
+                    
     return connections, None
