@@ -18,13 +18,14 @@ from .forest_utils.compete_add import *
 from .sv_interface.get_sv_data import *
 from .sv_interface.options import *
 from .sv_interface.build_files import *
-from .sv_interface.waveform import generate_physiologic_wave
+from .sv_interface.waveform import generate_physiologic_wave, wave
 from .sv_interface.build_results import make_results
 from .sv_interface.view_0d_result_plots import view_plots
 from .sv_interface.build_0d_run_script import run_0d_script
 from .sv_interface.locate import locate_0d_solver, locate_1d_solver
 from .sv_interface.export_3d_only import export_3d_only
 from .collision.collision import *
+from .utils.gcode.gcode import *
 from copy import deepcopy
 from itertools import combinations
 from tqdm import tqdm
@@ -35,7 +36,7 @@ from scipy.interpolate import splev, splprep
 import matplotlib.pyplot as plt
 import platform
 import pymeshfix
-from wrapt_timeout_decorator import *
+#from wrapt_timeout_decorator import *
 
 class tree:
     """
@@ -113,6 +114,7 @@ class tree:
         self.parameters['Pterm']    = kwargs.get('Pterm',60)*1333.22
         self.parameters['Qterm']    = kwargs.get('Qterm',0.125)/60
         self.parameters['edge_num'] = kwargs.get('edge_num',0)
+        self.parameters['rho']      = kwargs.get('rho',1.06)
 
     def set_assumptions(self,**kwargs):
         self.homogeneous = kwargs.get('homogeneous',True)
@@ -330,7 +332,7 @@ class tree:
         self.boundary = pickle.loads(file)
         file.close()
 
-    def export(self,steady=True,apply_distal_resistance=True,gui=True,cylinders=False,make=True):
+    def export(self,steady=True,apply_distal_resistance=True,gui=True,cylinders=False,make=True,global_edge_size=None):
         if cylinders:
             pv_data = []
             models = self.show(show=False)
@@ -344,7 +346,37 @@ class tree:
             time = [0, 1]
             flow = [self.data[0,22], self.data[0,22]]
         else:
-            time,flow = generate_physiologic_wave(self.data[0,22],self.data[0,21]*2)
+            time,flow = wave(self.data[0,22],self.data[0,21]*2) #changed wave function
+            time = time.tolist()
+            flow = flow.tolist()
+            flow[-1] = flow[0]
+        if apply_distal_resistance:
+            R = self.parameters['Pterm']/self.data[0,22]
+        else:
+            R = 0
+        if make:
+            num_caps = 1+2+int((self.parameters['edge_num']-1)/2)
+            options = file_options(num_caps,time=time,flow=flow,gui=gui,distal_resistance=R)
+            if global_edge_size is None:
+                options.set_mesh_options(global_edge_size=global_edge_size)
+            build(points,radii,normals,options)
+        return interp_xyz,interp_r,interp_xyzr
+
+    def export_truncated(self,steady=True,radius=None,indicies=None,apply_distal_resistance=True,gui=True,cylinders=False,make=True):
+        if cylinders:
+            pv_data = []
+            models = self.show(show=False)
+            for m in models:
+                pv_data.append(pv.PolyData(var_inp=m.GetOutput()))
+            merge = pv_data[0].merge(pv_data[1:])
+            return merge
+        interp_xyz,interp_r,interp_n,frames,branches,interp_xyzr = get_truncated_interpolated_sv_data(self.data,radius=radius,indicies=indicies)
+        points,radii,normals    = sv_data(interp_xyzr,interp_r,radius_buffer=self.radius_buffer)
+        if steady:
+            time = [0, 1]
+            flow = [self.data[0,22], self.data[0,22]]
+        else:
+            time,flow = wave(self.data[0,22],self.data[0,21]*2)
             time = time.tolist()
             flow = flow.tolist()
             flow[-1] = flow[0]
@@ -358,6 +390,23 @@ class tree:
             build(points,radii,normals,options)
         return interp_xyz,interp_r
 
+    def show_truncated(self,radius=None,indicies=None):
+        large,small = truncate(self.data,radius=radius,indicies=indicies)
+        combined = []
+        plotter = pv.Plotter()
+        models = []
+        for i in large:
+            combined += i
+        for i in range(self.data.shape[0]):
+            center = (self.data[i,0:3] + self.data[i,3:6])/2
+            m = pv.Cylinder(center=center,direction=self.data[i,12:15],radius=self.data[i,21],height=self.data[i,20])
+            if i in combined:
+                plotter.add_mesh(m,color='red')
+            else:
+                plotter.add_mesh(m,color='blue',opacity=0.4)
+        plotter.set_background('white')
+        return plotter
+
     def export_3d_solid(self,outdir=None,folder="3d_tmp"):
         if outdir is None:
             outdir = os.getcwd()+os.sep+folder
@@ -484,7 +533,7 @@ class tree:
                             file.write("{}  {}\n".format(bc_values["t"][i],bc_values["Q"][i]))
                     file.close()
                 else:
-                    time,flow = generate_physiologic_wave(self.data[vessel,22],self.data[vessel,21]*2)
+                    time,flow = wave(self.data[vessel,22],self.data[vessel,21]*2) # changed wave function
                     bc_values["Q"] = flow.tolist()
                     bc_values["t"] = time.tolist()
                     bc_values["Q"][-1] = bc_values["Q"][0]
@@ -563,6 +612,11 @@ class tree:
     def collision_free(self,outside_vessels,radius_buffer=0.01):
         return no_outside_collision(self,outside_vessels,radius_buffer=radius_buffer)
 
+    def export_gcode(self):
+        interp_xyz,interp_r,interp_n,frames,branches,interp_xyzr = get_interpolated_sv_data(self.data)
+        points,radii,normals    = sv_data(interp_xyzr,interp_r,radius_buffer=self.radius_buffer)
+        generate_gcode(points)
+
 class forest:
     def __init__(self,boundary=None,number_of_networks=1,
                  trees_per_network=[2],scale=None,start_points=None,
@@ -847,7 +901,7 @@ class forest:
     def connect(self,network_id=-1,buffer=None,curve_sample_size_min=5,curve_sample_size_max=11,curve_degree=3):
         self.forest_copy = self.copy()
         self.forest_copy.connections,self.forest_copy.assignments = connect(self.forest_copy,network_id=network_id,buffer=buffer)
-        self.forest_copy.connections,self.forest_copy.connected_forest = smooth(self.forest_copy,curve_sample_size_min=curve_sample_size_min,curve_sample_size_max=curve_sample_size_max,curve_degree=curve_degree)
+        self.forest_copy.connections,self.forest_copy.connected_forest,self.splines = smooth(self.forest_copy,curve_sample_size_min=curve_sample_size_min,curve_sample_size_max=curve_sample_size_max,curve_degree=curve_degree)
 
     def assign(self):
         self.connections,self.assignments = connect(self)
@@ -929,7 +983,7 @@ class forest:
                 def enablePrint():
                     sys.stdout = sys.__stdout__
 
-                @timeout(60)
+                #@timeout(60)
                 def tetrahedralize(tet):
                     tet.tetrahedralize(minratio=1.2)
                     return tet
@@ -1088,9 +1142,9 @@ class forest:
                     for vessel in range(len(reordered_points[tree])):
                         vessel_normals_flip = np.array(reordered_normals[tree][vessel])*-1
                         reordered_normals[tree][vessel] = vessel_normals_flip.tolist()
-                        final_points[0][vessel].extend(list(reversed(reordered_points[tree][vessel]))[1:])
-                        final_radii[0][vessel].extend(list(reversed(reordered_radii[tree][vessel]))[1:])
-                        final_normals[0][vessel].extend(list(reversed(reordered_normals[tree][vessel]))[1:])
+                        final_points[0][vessel].extend(list(reversed(reordered_points[tree][vessel]))[2:]) #changed
+                        final_radii[0][vessel].extend(list(reversed(reordered_radii[tree][vessel]))[2:]) #changed
+                        final_normals[0][vessel].extend(list(reversed(reordered_normals[tree][vessel]))[2:]) #changed 9-8-22
                         #make the connecting contours have equal average radii
                 else:
                     tmp_points  = []
@@ -1128,7 +1182,7 @@ class forest:
                     time = [0, 1]
                     flow = [self.networks[network][0].data[0,22], self.networks[network][0].data[0,22]]
                 else:
-                    time,flow = generate_physiologic_wave(self.networks[network][0].data[0,22],self.networks[network][0].data[0,21]*2)
+                    time,flow = wave(self.networks[network][0].data[0,22],self.networks[network][0].data[0,21]*2) # changed wave function
                     time = time.tolist()
                     flow = flow.tolist()
                     flow[-1] = flow[0]
